@@ -1,12 +1,6 @@
-#!/usr/bin/env python3
-# -*- coding: utf-8 -*-
-#
 # cssselect2 documentation build configuration file.
 
-import codecs
-import re
-from os import path
-
+import cssselect2
 
 # Add any Sphinx extension module names here, as strings. They can be
 # extensions coming with Sphinx (named 'sphinx.ext.*') or your custom ones.
@@ -23,17 +17,14 @@ master_doc = 'index'
 
 # General information about the project.
 project = 'cssselect2'
-copyright = '2012-2017, Simon Sapin'
+copyright = 'Simon Sapin and contributors'
 
 # The version info for the project you're documenting, acts as replacement for
 # |version| and |release|, also used in various other places throughout the
 # built documents.
 #
 # The full version, including alpha/beta/rc tags.
-release = re.search("VERSION = '([^']+)'", codecs.open(
-    path.join(path.dirname(path.dirname(__file__)), 'cssselect2', '__init__.py'),
-    encoding='utf-8',
-).read().strip()).group(1)
+release = cssselect2.__version__
 
 # The short X.Y version.
 version = '.'.join(release.split('.')[:2])
@@ -43,16 +34,30 @@ version = '.'.join(release.split('.')[:2])
 exclude_patterns = ['_build']
 
 # The name of the Pygments (syntax highlighting) style to use.
-pygments_style = 'sphinx'
+pygments_style = 'monokai'
 
 # The theme to use for HTML and HTML Help pages.  See the documentation for
 # a list of builtin themes.
-html_theme = 'sphinx_rtd_theme'
+html_theme = 'furo'
+
+html_theme_options = {
+    'top_of_page_buttons': ['edit'],
+    'source_edit_link': 'https://github.com/Kozea/cssselect2/edit/main/docs/{filename}',
+}
+
+# Favicon URL
+html_favicon = 'https://www.courtbouillon.org/static/images/favicon.png'
 
 # Add any paths that contain custom static files (such as style sheets) here,
 # relative to this directory. They are copied after the builtin static files,
 # so a file named "default.css" will overwrite the builtin "default.css".
-html_static_path = ['_static']
+html_static_path = []
+
+# These paths are either relative to html_static_path
+# or fully qualified paths (eg. https://...)
+html_css_files = [
+    'https://www.courtbouillon.org/static/docs-furo.css',
+]
 
 # Output file base name for HTML help builder.
 htmlhelp_basename = 'cssselect2doc'
@@ -61,7 +66,7 @@ htmlhelp_basename = 'cssselect2doc'
 # (source start file, name, description, authors, manual section).
 man_pages = [
     ('index', 'cssselect2', 'cssselect2 Documentation',
-     ['Simon Sapin'], 1)
+     ['Simon Sapin and contributors'], 1)
 ]
 
 # Grouping the document tree into Texinfo files. List of tuples
@@ -69,12 +74,14 @@ man_pages = [
 #  dir menu entry, description, category)
 texinfo_documents = [
   ('index', 'cssselect2', 'cssselect2 Documentation',
-   'Simon Sapin', 'cssselect2', 'One line description of project.',
+   'Simon Sapin', 'cssselect2',
+   'A straightforward implementation of CSS3 Selectors.',
    'Miscellaneous'),
 ]
 
 # Example configuration for intersphinx: refer to the Python standard library.
 intersphinx_mapping = {
-    'py2': ('http://docs.python.org/2', None),
-    'py3': ('http://docs.python.org/3', None),
-    'webencodings': ('http://pythonhosted.org/webencodings/', None)}
+    'python': ('https://docs.python.org/3/', None),
+    'webencodings': ('https://pythonhosted.org/webencodings/', None),
+    'tinycss2': ('https://doc.courtbouillon.org/tinycss2/latest/', None),
+}
